django-signature
================

Application to parse & make PDFs with Django

http://bitbucket.org/bearstech/django-latex/

Beta : not really for production use

Features :
----------

- LaTeX :

   + Parse LaTeX Document
   + Render LaTeX Document Objects
   + Generate Base PDF Files
   + Combine simple LaTeX Documents

- Good test coverage

Todo :
------

 - ... much more

Examples :
----------

Usage examples::

    from latex import LatexDocument
    ltxdoc = LatexDocument(latexstr)
    print ltxdoc.packages
    print ltxdoc.preamble

    ltxdoc2 = LatexDocument(latexstr2)
    ltxdoc3 = ltxdoc + ltxdoc2
    ltxdoc3.as_latex()

    # If some files have to be inclued
    ltxdoc3.add_file("/home/cyberj/lolcat_1182.png", "lolcat.png")

    f = open("/home/cyberj/motivational_4242.png", "rb")
    ltxdoc3.add_file(f, "motivational.png")

    pdf = ltxdoc3.as_pdf()

If ``pdflatex`` fails, it raises ``LatexDocument.LatexPdfGenerationError`` and clean
tempdir. To preserve temporary directory give ``debug=True`` to ``as_pdf`` method.

Tests :
-------

- cd tests

- python bootstrap

- ./bin/buildout.py -v

- ./bin/test-1.2 or ./bin/test-1.1

Requirements :
--------------

- Django >= 1.1
- pdflatex (and LaTeX distro)

Debian packages
----------------

-  dblatex                        Produces DVI, PostScript, PDF documents from DocBook sources
-  latex-xcolor                   Easy driver-independent TeX class for color
-  preview-latex-style            extraction of elements from LaTeX documents as graphics
-  texlive-latex-base             TeX Live: Basic LaTeX packages
-  texlive-latex-base-doc         TeX Live: Documentation files for texlive-latex-base
-  texlive-latex-extra            TeX Live: LaTeX supplementary packages
-  texlive-latex-extra-doc        TeX Live: Documentation files for texlive-latex-extra
-  texlive-latex-recommended      TeX Live: LaTeX recommended packages
-  texlive-latex-recommended-doc  TeX Live: Documentation files for texlive-latex-recommended

